package sep

import (
	"context"
	"net/http"
	"strconv"

	"repository.basistech.ru/BASIS/decort-golang-sdk/internal/validators"
)

// AddPoolRequest struct to add pool to storage endpoint (SEP)
type AddPoolRequest struct {
	// ID of SEP to add new pool
	// Required: true
	SEPID uint64 `url:"sep_id" json:"sep_id" validate:"required"`

	// method Async/Sync
	// Default: true
	// Required: false
	Sync bool `url:"sync" json:"sync"`

	// Pool structure which contains fields such as "name", "types", "accessAccountIds", "accessResGroupIds"
	// Required: true
	Pool string `url:"pool" json:"pool" validate:"required"`
}

// AddPool adds pool to SEP
func (s SEP) AddPool(ctx context.Context, req AddPoolRequest) (bool, error) {
	err := validators.ValidateRequest(req)
	if err != nil {
		return false, validators.ValidationErrors(validators.GetErrors(err))
	}

	url := "/cloudbroker/sep/addPool"

	res, err := s.client.DecortApiCall(ctx, http.MethodPost, url, req)
	if err != nil {
		return false, err
	}

	result, err := strconv.ParseBool(string(res))
	if err != nil {
		return false, err
	}

	return result, nil
}
